@@ -25,6 +25,7 @@ export class Global {
     public static get version(): string { return Global._version }
     public static set version(version: string) {
         Global._version = version
+        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
         Global._onVersionSet.emit(void 0);
     }
 
@@ -44,6 +45,7 @@ export class Global {
     public static get domain(): string { return Global._domain }
     public static set domain(domain: string) {
         Global._domain = domain
+        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
         Global._onDomainChange.emit(domain);
     }
 
@@ -52,11 +54,37 @@ export class Global {
 
     private static _shouldLogOnRender: boolean = false
     public static get shouldLogOnRender(): boolean { return Global._shouldLogOnRender }
+    static __setShouldLogOnRender(shouldLogOnRender: boolean) {
+        Global._shouldLogOnRender = shouldLogOnRender
+        return 'shouldLogOnRender is now set to ' + Global._shouldLogOnRender
+    }
+
+    private static _shouldLogOnEmit: boolean = false
+    public static get shouldLogOnEmit(): boolean { return Global._shouldLogOnEmit }
+    static __setShouldLogOnEmit(shouldLogOnEmit: boolean) {
+        Global._shouldLogOnEmit = shouldLogOnEmit
+        return 'shouldLogOnEmit is now set to ' + Global._shouldLogOnEmit
+    }
+
+    private static _shouldLogOnPoll: boolean = false
+    public static get shouldLogOnPoll(): boolean { return Global._shouldLogOnPoll }
+    static __setShouldLogOnPoll(shouldLogOnPoll: boolean) {
+        Global._shouldLogOnPoll = shouldLogOnPoll
+        return 'shouldLogOnPoll is now set to ' + Global._shouldLogOnPoll
+    }
+
+    private static _shouldLogOnSafeSetState: boolean = false
+    public static get shouldLogOnSafeSetState(): boolean { return Global._shouldLogOnSafeSetState }
+    static __setShouldLogOnSafeSetState(shouldLogOnSafeSetState: boolean) {
+        Global._shouldLogOnSafeSetState = shouldLogOnSafeSetState
+        return 'shouldLogOnSafeSetState is now set to ' + Global._shouldLogOnSafeSetState
+    }
 
     private static _inQuestionMode: boolean = false
     public static get inQuestionMode(): boolean { return Global._inQuestionMode }
     public static set inQuestionMode(inQuestionMode: boolean) {
         Global._inQuestionMode = inQuestionMode
+        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
         Global._onInQuestionModeChange.emit(inQuestionMode)
     }
 
@@ -84,7 +112,20 @@ export class Global {
 
     private static _metadata: OptumiMetadataTracker = undefined
     public static get metadata(): OptumiMetadataTracker { return Global._metadata }
-    public static set metadata(metadata: OptumiMetadataTracker) { Global._metadata = metadata }
+    public static set metadata(metadata: OptumiMetadataTracker) {
+        Global._metadata = metadata
+        // if (Global._metadata.getMetadata().metadata.version === 'DEV') {
+        //     (window as any).setShouldLogOnRender = Global.__setShouldLogOnRender;
+        //     (window as any).setShouldLogOnEmit = Global.__setShouldLogOnEmit;
+        //     (window as any).setShouldLogOnPoll = Global.__setShouldLogOnPoll;
+        //     (window as any).setShouldLogOnSafeSetState = Global.__setShouldLogOnSafeSetState;
+        // } else {
+        //     (window as any).setShouldLogOnRender = undefined;
+        //     (window as any).setShouldLogOnEmit = undefined;
+        //     (window as any).setShouldLogOnPoll = undefined;
+        //     (window as any).setShouldLogOnSafeSetState = undefined;
+        // }
+    }
 
     private static _docManager: IDocumentManager = undefined
     public static get docManager(): IDocumentManager { return Global._docManager }
@@ -94,15 +135,12 @@ export class Global {
     public static get user(): User { return Global._user }
     public static set user(user: User) {
         if (this._user != null) {
-            // Stop polling for apps if user is logging out/ being logged out
-            for (let app of this._user.appTracker.activeJobs) {
-                app.stopPolling();
-            }
-            for (let app of this._user.appTracker.activeSessions) {
-                app.stopPolling();
-            }
+            this._user.appTracker.stopPolling();
+        }
+        if (user == null) {
+            if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
+            Global._onNullUser.emit(null)
         }
-        if (user == null) Global._onNullUser.emit(null);
         Global._user = user;
         // Reset 401 counter
         Global.consecutive401s = 0;
@@ -114,6 +152,7 @@ export class Global {
         Global.lastBudgetCost = 0;
         Global.lastDataConnectors = [];
         // Signal
+        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
         Global._onUserChange.emit(user)
     }
 
@@ -167,6 +206,7 @@ export class Global {
 
     // Poll for machines in the background
     public static updateMachines = () => {
+        if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
         setTimeout(Global.updateMachines, 30000);
         if (Global.user != null) {
             const settings = ServerConnection.makeSettings();
