@@ -70,8 +70,8 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
     }
 
 	// The contents of the component
-	render() {
-        if (Global.shouldLogOnRender) console.log('LeftPanelRender (' + new Date().getSeconds() + ')');
+	public render = (): JSX.Element => {
+        if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
 		return (
 			<GlobalThemeDiv component='div' style={{
 				height: '100%',
@@ -165,8 +165,8 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
 	theme: Theme = this.getTheme();
 
 	private handleVersionSet = () => this.forceUpdate()
-	private handleUserChange = () => this.setState({loggedIn: Global.user != null})
-	private handleNullUserChange = () => this.setState({loggedIn: false})
+	private handleUserChange = () => this.safeSetState({loggedIn: Global.user != null})
+	private handleNullUserChange = () => this.safeSetState({loggedIn: false})
 
 	//TODO:JJ should this be async?
 	private handleThemeChange = async () => {
@@ -175,7 +175,7 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
 	}
 
 	// Will be called automatically when the component is mounted
-	componentDidMount = () => {
+	public componentDidMount = () => {
 		this._isMounted = true;
 		Global.onVersionSet.connect(this.handleVersionSet);
 		Global.onNullUser.connect(this.handleNullUserChange);
@@ -209,7 +209,7 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
 	}
 
 	// Will be called automatically when the component is unmounted
-	componentWillUnmount = () => {
+	public componentWillUnmount = () => {
 		Global.onVersionSet.disconnect(this.handleVersionSet);
 		Global.onNullUser.disconnect(this.handleNullUserChange);
 		Global.onUserChange.disconnect(this.handleUserChange);
@@ -217,11 +217,33 @@ class OptumiLeftPanel extends React.Component<IProps, IState> {
 		this._isMounted = false;
 	}
 
+	private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
+
 	public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
-            if (Global.shouldLogOnRender) console.log('SuppressedRender')
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
             return false;
         } catch (error) {
             return true;
