@@ -7,12 +7,13 @@
 
 import * as React from 'react';
 import { Global } from '../Global';
-import { Paper } from '@material-ui/core';
+import { darken, lighten, Paper } from '@material-ui/core';
 
 interface IProps {
     style?: React.CSSProperties
     children?: JSX.Element | JSX.Element[]
     statusColor: StatusColor | string
+    opened: boolean
 }
 
 interface IState {}
@@ -31,12 +32,31 @@ export enum StatusColor {
 
 export class StatusWrapper extends React.Component<IProps, IState> {
 
+    private isLightMode: boolean = false;
+
+    constructor(props: IProps) {
+        super(props);
+        this.isLightMode = Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme)
+    }
+
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+        var color: string;
+        if (this.props.statusColor.startsWith('var')) {
+            color = getComputedStyle(document.documentElement).getPropertyValue(this.props.statusColor.replace('var(', '').replace(')', '')).trim();
+        } else {
+            color = this.props.statusColor;
+        }
+
+        console.log(color)
 
         return (
             <div style={this.props.style}>
-                <Paper elevation={0} style={{marginLeft: '-6px', background: this.props.statusColor}}>
+                <Paper elevation={0} style={{
+                    marginLeft: '-6px', 
+                    background: this.props.opened ? (this.isLightMode ? darken(color, 0.5) : lighten(color, 0.5)) : color,
+                    transition: 'background 750ms cubic-bezier(0.4, 0, 0.2, 1) 0ms',
+                }}>
                     <div style={{marginLeft: '6px', padding: '2px'}}>
                         {this.props.children}
                     </div>
