@@ -7,7 +7,7 @@
 
 import * as React from 'react';
 import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { FullWidthTextBox, SubHeader } from '../../core';
+import { TextBox, SubHeader } from '../../core';
 import { OutlinedInput, IconButton, Accordion, AccordionSummary, AccordionDetails, withTheme, Theme } from '@material-ui/core';
 import { Global } from '../../Global';
 import { FileUploadMetadata } from '../../models/FileUploadMetadata';
@@ -23,7 +23,7 @@ import { AddDataConnectorsPopup } from './AddDataConnectorsPopup';
 import { DataConnectorUploadMetadata } from '../../models/DataConnectorUploadMetadata';
 
 import { ServerConnection } from '@jupyterlab/services';
-import DataConnectorDirListingItemIcon from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
+import DataConnectorDirListingItemIcon, { DataService } from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
 import { ExpandMore, WarningRounded } from '@material-ui/icons';
 
 // const emDirNotFile = 'Path is a directory, not a file'
@@ -84,10 +84,13 @@ interface IState {
     // Here is where we will keep a list of the file paths that were entered successfully but no longer exist on the disk
     problemFiles: string[]
     problemDataConnectors: string[]
+    packagesExpanded: boolean
     filesExpanded: boolean
 }
 
 class FilesPanel extends React.Component<IProps, IState> {
+    private _isMounted = false
+
     StyledOutlinedInput: any
     textField: React.RefObject<HTMLInputElement>
     timeout: NodeJS.Timeout
@@ -102,6 +105,7 @@ class FilesPanel extends React.Component<IProps, IState> {
             filePath: '',
             problemFiles: [],
             problemDataConnectors: [],
+            packagesExpanded: false,
             filesExpanded: false,
         }
     }
@@ -125,7 +129,7 @@ class FilesPanel extends React.Component<IProps, IState> {
         return uploads.requirements;
     }
 
-    private saveRequirements = async (value: string): Promise<string> => {
+    private saveRequirements = (value: string): string => {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
         const uploads: UploadMetadata = optumi.metadata.upload;
@@ -157,28 +161,56 @@ class FilesPanel extends React.Component<IProps, IState> {
     }
 
     public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         const files = Global.metadata.getMetadata().metadata.upload.files;
         const dataConnectors = Global.metadata.getMetadata().metadata.upload.dataConnectors;
         return (
             <div style={this.props.style}>
-                <div>
-                    <SubHeader title='Packages' style={{flexGrow: 1}}/>
-                    <div style={{display: 'flex', width: '100%'}}>
-                        <FullWidthTextBox
-                            multiline
-                            getValue={this.getRequirementsValue}
-                            saveValue={this.saveRequirements}
-                            checkForError={() => ''}
-                            placeholder={'package==version'}
-                            helperText='Enter python packages'
-                            // typingText='Press ↩'
-                        />
-                    </div>
-                </div>
+                <StyledAccordion
+                    variant={'outlined'}
+                    expanded={this.state.packagesExpanded}
+                    onChange={() => this.safeSetState({packagesExpanded: !this.state.packagesExpanded})}
+                    style={{background: 'var(--jp-layout-color1)'}}
+                >
+                    <StyledAccordionSummary
+                        expandIcon={<ExpandMore />}
+                    >
+                        <SubHeader title='Packages' />
+                        <span style={{
+                            margin: 'auto',
+                            flexGrow: 1,
+                            textAlign: 'center',
+                            opacity: this.state.packagesExpanded ? 0 : 0.5,
+                            transitionDuration: '217ms',
+                            whiteSpace: 'nowrap',
+                            fontSize: '12px',
+                            fontStyle: 'italic',
+                        }}>
+                            {(() => {
+                                const requirements = Global.metadata.getMetadata().metadata.upload.requirements
+                                const numRequirements = requirements === '' ? 0 : requirements.split('\n').filter(line => line !== '').length
+                                if (numRequirements > 0) {
+                                    return numRequirements + ' requirement' + (numRequirements > 1 ? 's' : '')
+                                }
+                            })()}
+                        </span>
+                    </StyledAccordionSummary>
+                    <StyledAccordionDetails>
+                        <div style={{display: 'flex', width: '100%'}}>
+                            <TextBox<string>
+                                multiline
+                                getValue={this.getRequirementsValue}
+                                saveValue={this.saveRequirements}
+                                placeholder={'package==version'}
+                                style={{padding: '0px 0px 6px 0px'}}
+                            />
+                        </div>
+                    </StyledAccordionDetails>
+                </StyledAccordion>
                 <StyledAccordion
                     variant={'outlined'}
                     expanded={this.state.filesExpanded}
-                    onChange={() => this.setState({filesExpanded: !this.state.filesExpanded})}
+                    onChange={() => this.safeSetState({filesExpanded: !this.state.filesExpanded})}
                     style={{background: 'var(--jp-layout-color1)'}}
                 >
                     <StyledAccordionSummary
@@ -271,7 +303,7 @@ class FilesPanel extends React.Component<IProps, IState> {
                                                 }
                                                 // optumi.upload.files = (optumi.upload.files as UploadVarMetadata[]).filter(x => x.path !== (event.currentTarget as HTMLButtonElement).id.replace('-delete', ''));
                                                 tracker.setMetadata(optumi);
-                                                if (this.state.problemFiles.includes(value.path)) this.setState({ problemFiles: this.state.problemFiles.filter(x => x != value.path) });
+                                                if (this.state.problemFiles.includes(value.path)) this.safeSetState({ problemFiles: this.state.problemFiles.filter(x => x != value.path) });
                                             }}
                                             noLongerExists={this.state.problemFiles.includes(value.path)}
                                         />
@@ -294,7 +326,7 @@ class FilesPanel extends React.Component<IProps, IState> {
                                                 }
                                                 // optumi.upload.files = (optumi.upload.files as UploadVarMetadata[]).filter(x => x.path !== (event.currentTarget as HTMLButtonElement).id.replace('-delete', ''));
                                                 tracker.setMetadata(optumi);
-                                                if (this.state.problemDataConnectors.includes(value.name)) this.setState({ problemDataConnectors: this.state.problemDataConnectors.filter(x => x != value.name) });
+                                                if (this.state.problemDataConnectors.includes(value.name)) this.safeSetState({ problemDataConnectors: this.state.problemDataConnectors.filter(x => x != value.name) });
                                             }}
                                             noLongerExists={this.state.problemDataConnectors.includes(value.name)}
                                         />
@@ -302,7 +334,6 @@ class FilesPanel extends React.Component<IProps, IState> {
                                 )}
                             </>
                         )}
-						<div style={{margin: '6px'}}/>
                     </StyledAccordionDetails>
                 </StyledAccordion>
             </div>
@@ -311,6 +342,7 @@ class FilesPanel extends React.Component<IProps, IState> {
 
     private refreshFiles = async () => {
         if (this.refreshingFiles) {
+            if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
             setTimeout(this.refreshFiles, 60000);
             const metadata = Global.metadata.getMetadata();
             const files = metadata.metadata.upload.files;
@@ -319,7 +351,7 @@ class FilesPanel extends React.Component<IProps, IState> {
                 if (!this.state.problemFiles.includes(file.path)) {
                     const barr = await FileServerUtils.checkIfPathExists(file.path);
                     if (!barr[0]) {
-                        this.setState({ problemFiles: this.state.problemFiles.concat([file.path]) });
+                        this.safeSetState({ problemFiles: this.state.problemFiles.concat([file.path]) });
                     }
                 }
             }
@@ -328,6 +360,7 @@ class FilesPanel extends React.Component<IProps, IState> {
 
     private refreshDataConnectors = async () => {
         if (this.refreshingDataConnectors) {
+            if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
             setTimeout(this.refreshDataConnectors, 60000);
             const metadata = Global.metadata.getMetadata();
             const dataConnectors = metadata.metadata.upload.dataConnectors;
@@ -344,7 +377,7 @@ class FilesPanel extends React.Component<IProps, IState> {
                 if (!this.state.problemDataConnectors.includes(dataConnector.name)) {
                     const exists = dataConnectorsFromController.map(x => x.name).includes(dataConnector.name);
                     if (!exists) {
-                        this.setState({ problemDataConnectors: this.state.problemDataConnectors.concat([dataConnector.name]) });
+                        this.safeSetState({ problemDataConnectors: this.state.problemDataConnectors.concat([dataConnector.name]) });
                     }
                 }
             }
@@ -355,7 +388,8 @@ class FilesPanel extends React.Component<IProps, IState> {
 	private handleLabShellChange = () => {this.forceUpdate()}
 
 	// Will be called automatically when the component is mounted
-	componentDidMount = () => {
+	public componentDidMount = () => {
+        this._isMounted = true
         this.refreshingFiles = true;
         this.refreshingDataConnectors = true;
         this.refreshFiles();
@@ -365,18 +399,41 @@ class FilesPanel extends React.Component<IProps, IState> {
 	}
 
 	// Will be called automatically when the component is unmounted
-	componentWillUnmount = () => {
+	public componentWillUnmount = () => {
         Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
         Global.labShell.currentChanged.disconnect(this.handleLabShellChange);
         this.refreshingFiles = false;
         this.refreshingDataConnectors = false;
+        this._isMounted = false
     }
+
+    private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
     
     public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
-            if (Global.shouldLogOnRender) console.log('SuppressedRender')
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
             return false;
         } catch (error) {
             return true;
@@ -407,14 +464,15 @@ class ResourceFile extends React.Component<RFProps, RFState> {
     }
 
     public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div
                 style={{display: 'flex', width: '100%', position: 'relative'}}
                 onMouseOver={() => {
-                    this.setState({hovering: true})
+                    this.safeSetState({hovering: true})
                 }}
                 onMouseOut={() => {
-                    this.setState({hovering: false})
+                    this.safeSetState({hovering: false})
                 }}
             >
                 <div style={{
@@ -477,11 +535,41 @@ Path: ${this.props.file.path.replace(/\/[^\/]*$/, '')}`
         )
     }
 
+    public componentDidMount = () => {
+        this._isMounted = true
+    }
+
+    public componentWillUnmount = () => {
+        this._isMounted = false
+    }
+
+    private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
+
     public shouldComponentUpdate = (nextProps: RFProps, nextState: RFState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
-            if (Global.shouldLogOnRender) console.log('SuppressedRender')
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
             return false;
         } catch (error) {
             return true;
@@ -510,14 +598,15 @@ class ResourceDataConnector extends React.Component<RDCProps, RDCState> {
     }
 
     public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div
                 style={{display: 'flex', width: '100%', position: 'relative'}}
                 onMouseOver={() => {
-                    this.setState({hovering: true})
+                    this.safeSetState({hovering: true})
                 }}
                 onMouseOut={() => {
-                    this.setState({hovering: false})
+                    this.safeSetState({hovering: false})
                 }}
             >
                 <div style={{
@@ -551,6 +640,27 @@ class ResourceDataConnector extends React.Component<RDCProps, RDCState> {
                         dataService={this.props.dataConnector.dataService}
                     />
                     <div
+                        title={(() => {
+                            var location = ''
+                            switch (this.props.dataConnector.dataService) {
+                                case DataService.AMAZON_S3:
+                                    location = 's3';
+                                    break;
+                                case DataService.GOOGLE_CLOUD_STORAGE:
+                                    location = 'gcp';
+                                    break;
+                                case DataService.GOOGLE_DRIVE:
+                                    location = 'gdrive';
+                                    break;
+                                case DataService.KAGGLE:
+                                    location = 'kaggle';
+                                    break;
+                                case DataService.WASABI:
+                                    location = 'wasabi';
+                                    break;
+                            }
+                            return 'Files will be accessible in ~/' + location + '/';
+                        })()}
                         style={{
                             margin: 'auto 0px',
                             overflow: 'hidden', 
@@ -567,11 +677,41 @@ class ResourceDataConnector extends React.Component<RDCProps, RDCState> {
         )
     }
 
+    public componentDidMount = () => {
+        this._isMounted = true
+    }
+
+    public componentWillUnmount = () => {
+        this._isMounted = false
+    }
+
+    private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
+
     public shouldComponentUpdate = (nextProps: RDCProps, nextState: RDCState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
-            if (Global.shouldLogOnRender) console.log('SuppressedRender')
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
             return false;
         } catch (error) {
             return true;
