@@ -76,7 +76,7 @@ export default class DataConnectorDirListingContent extends React.Component<IPro
                                         }
                                     }
                                     if (event.ctrlKey) {
-                                        const newSelected = this.state.selected
+                                        const newSelected = [...this.state.selected]
                                         if (newSelected.includes(dataConnector)) {
                                             newSelected.splice(newSelected.indexOf(dataConnector), 1)
                                         } else {
@@ -85,7 +85,7 @@ export default class DataConnectorDirListingContent extends React.Component<IPro
                                         this.safeSetState({selected: newSelected})
                                         this.lastClicked = dataConnector
                                     } else if (event.shiftKey) {
-                                        const newSelected = this.state.selected
+                                        const newSelected = [...this.state.selected]
                                         let index = sortedDataConnectors.indexOf(dataConnector)
                                         const lastClickedIndex = sortedDataConnectors.indexOf(this.lastClicked)
                                         const direction = index < lastClickedIndex ? 1 : -1
