@@ -55,7 +55,7 @@ export default class DirListingContent extends React.Component<IProps, IState> {
                                 }
                             }
                             if (event.ctrlKey) {
-                                const newSelected = this.state.selected
+                                const newSelected = [...this.state.selected]
                                 if (newSelected.includes(file)) {
                                     newSelected.splice(newSelected.indexOf(file), 1)
                                 } else {
@@ -64,7 +64,7 @@ export default class DirListingContent extends React.Component<IProps, IState> {
                                 this.safeSetState({selected: newSelected})
                                 this.lastClicked = file
                             } else if (event.shiftKey) {
-                                const newSelected = this.state.selected
+                                const newSelected = [...this.state.selected]
                                 let index = sortedFiles.indexOf(file)
                                 const lastClickedIndex = sortedFiles.indexOf(this.lastClicked)
                                 const direction = index < lastClickedIndex ? 1 : -1
@@ -118,4 +118,4 @@ export default class DirListingContent extends React.Component<IProps, IState> {
 			}
 		}
 	}
-}
\ No newline at end of file
+}
