@@ -9,6 +9,7 @@ import * as React from 'react';
 import { SubHeader } from '../../../core';
 import { Global } from '../../../Global';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
+import ExtraInfo from '../../../utils/ExtraInfo';
 
 import { OutlinedResourceRadio } from '../OutlinedResourceRadio';
 
@@ -34,7 +35,7 @@ export class LaunchMode extends React.Component<IProps, IState> {
     }
 
     public render = (): JSX.Element => {
-        if (Global.shouldLogOnRender) console.log('ComputeBasicRender (' + new Date().getSeconds() + ')');
+        if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         const value = this.getValue();
         return (
             <>
@@ -46,8 +47,12 @@ export class LaunchMode extends React.Component<IProps, IState> {
                         width: '100%',
                     }}
                 >
-                    <OutlinedResourceRadio beta label={"Session"} hexColor={'#afaab0'} selected={value == "Session"} handleClick={() => this.saveValue("Session")}/>
-                    <OutlinedResourceRadio label={"Job"} hexColor={'#afaab0'} selected={value == "Job"} handleClick={() => this.saveValue("Job")}/>
+                    <ExtraInfo reminder='Run an interactive session'>
+                        <OutlinedResourceRadio beta label={'Session'} hexColor={'#afaab0'} selected={value == "Session"} handleClick={() => this.saveValue("Session")}/>
+                    </ExtraInfo>
+                    <ExtraInfo reminder='Run a batch job'>
+                        <OutlinedResourceRadio label={"Job"} hexColor={'#afaab0'} selected={value == "Job"} handleClick={() => this.saveValue("Job")}/>
+                    </ExtraInfo>
                 </div>
             </>
         )
@@ -56,12 +61,12 @@ export class LaunchMode extends React.Component<IProps, IState> {
     private handleMetadataChange = () => { this.forceUpdate() }
 
     // Will be called automatically when the component is mounted
-	componentDidMount = () => {
+	public componentDidMount = () => {
         Global.metadata.getMetadataChanged().connect(this.handleMetadataChange);
 	}
 
 	// Will be called automatically when the component is unmounted
-	componentWillUnmount = () => {
+	public componentWillUnmount = () => {
         Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
 	}
 
@@ -69,7 +74,7 @@ export class LaunchMode extends React.Component<IProps, IState> {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
-            if (Global.shouldLogOnRender) console.log('SuppressedRender')
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
             return false;
         } catch (error) {
             return true;
