@@ -47,6 +47,8 @@ interface IProps {
     app: App
     onOpen?: () => void
 	onClose?: () => void
+    onMouseOver?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
+    onMouseOut?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
 }
 
 interface IState {
@@ -57,6 +59,7 @@ interface IState {
 
 // TODO:Beck The popup needs to be abstracted out, there is too much going on to reproduce it in more than one file
 export class DetailsDialog extends React.Component<IProps, IState> {
+    private _isMounted = false
 
     constructor(props: IProps) {
         super(props);
@@ -69,24 +72,32 @@ export class DetailsDialog extends React.Component<IProps, IState> {
     
     private handleClickOpen = () => {
         if (this.props.onOpen) this.props.onOpen()
-		this.setState({ open: true });
+		this.safeSetState({ open: true });
 	}
 
 	private handleClose = () => {
-        this.setState({ open: false });
+        this.safeSetState({ open: false });
         if (this.props.onClose) this.props.onClose()
 	}
 	
 	private handleInputLineChange = (event: React.ChangeEvent<HTMLInputElement>) => {
-        this.setState({ inputLine: event.target.value });
+        this.safeSetState({ inputLine: event.target.value });
     }
 
     private handleKeyDown = (event: React.KeyboardEvent) => {
         if (event.key == 'Enter') {
-            this.setState({ inputLine: ''}), 
+            this.safeSetState({ inputLine: ''}), 
             this.props.app.modules[0].pushModuleInput(this.state.inputLine);
         }
     }
+    
+    private handleMouseOver = (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => {
+        if (this.props.onMouseOver) this.props.onMouseOver(event);
+    }
+
+    private handleMouseOut = (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => {
+        if (this.props.onMouseOut) this.props.onMouseOut(event);
+    }
 
     private openSession = () => {
         window.open('http://localhost:' + this.props.app.sessionPort + '?token=' + this.props.app.sessionToken, '_blank');
@@ -101,12 +112,12 @@ export class DetailsDialog extends React.Component<IProps, IState> {
         notebook['cells'].shift();
         FileServerUtils.saveNotebook(path, notebook).then((success: boolean) => { Global.docManager.open(path) });
         // Close the dialog
-        this.setState({ open: false });
+        this.safeSetState({ open: false });
     }
 
     public render = (): JSX.Element => {
         var i = 0;
-        if (Global.shouldLogOnRender) console.log('DetailsDialogRender (' + new Date().getSeconds() + ')');
+        if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
                 <IconButton
@@ -117,6 +128,8 @@ export class DetailsDialog extends React.Component<IProps, IState> {
                         height: '36px',
                         padding: '3px',
                     }}
+                    onMouseOver={this.handleMouseOver}
+                    onMouseOut={this.handleMouseOut}
                 >
                     <PopupIcon
                         style={{
@@ -209,7 +222,7 @@ export class DetailsDialog extends React.Component<IProps, IState> {
                                 <div style={{padding: '6px'}}>
                                     <Tabs
                                         value={this.state.selectedPanel}
-                                        onChange={(event, newValue) => this.setState({selectedPanel: newValue})}
+                                        onChange={(event, newValue) => this.safeSetState({selectedPanel: newValue})}
                                         orientation='vertical'
                                         variant='fullWidth'
                                         indicatorColor='primary'
@@ -366,4 +379,34 @@ export class DetailsDialog extends React.Component<IProps, IState> {
             </>
         )
     }
+
+    public componentDidMount = () => {
+        this._isMounted = true
+    }
+
+    public componentWillUnmount = () => {
+        this._isMounted = false
+    }
+
+    private safeSetState = (map: any) => {
+		if (this._isMounted) {
+			let update = false
+			try {
+				for (const key of Object.keys(map)) {
+					if (JSON.stringify(map[key]) !== JSON.stringify((this.state as any)[key])) {
+						update = true
+						break
+					}
+				}
+			} catch (error) {
+				update = true
+			}
+			if (update) {
+				if (Global.shouldLogOnSafeSetState) console.log('SafeSetState (' + new Date().getSeconds() + ')');
+				this.setState(map)
+			} else {
+				if (Global.shouldLogOnSafeSetState) console.log('SuppressedSetState (' + new Date().getSeconds() + ')');
+			}
+		}
+	}
 }
