@@ -49,7 +49,7 @@ export class ScrollableDiv extends React.Component<IProps, IState> {
 	}
 
     public render = (): JSX.Element => {
-        if (Global.shouldLogOnRender) console.log('ScrollableDivRender (' + new Date().getSeconds() + ')');
+        if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
 
         return (
             <div style={{overflow: 'auto', width: '100%', height: '100%', padding: "12px", whiteSpace: 'pre'}} ref={this.element}>
@@ -98,7 +98,7 @@ export class ScrollableDiv extends React.Component<IProps, IState> {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
-            if (Global.shouldLogOnRender) console.log('SuppressedRender')
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
             return false;
         } catch (error) {
             return true;
