@@ -34,7 +34,7 @@ interface IState {}
 
 const emUpSub = 'Upgrade subscription to unlock'
 
-const LABEL_WIDTH = '68px'
+const LABEL_WIDTH = '80px'
 
 interface IAccountGeneralSubMenuState {}
 
@@ -173,9 +173,9 @@ export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimits
                         getValue={this.getMaxJobsValue}
                         saveValue={this.saveMaxJobsValue}
                         unstyleUnitValue={(value: string) => { return value.replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value) }}
-                        label='Jobs'
+                        label='Jobs/Sessions'
                         labelWidth={LABEL_WIDTH}
-                        helperText={'Max number of concurrent jobs'}
+                        helperText={'Max combined number of concurrent jobs and sessions'}
                         disabledMessage={emUpSub}
                     />
                     <TextBox<number>
@@ -541,7 +541,7 @@ export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountCo
                             ).then((response: Response) => {
                                 Global.handleResponse(response);
                             }).then(() => {
-                                var newDataConnectors = this.state.dataConnectors
+                                var newDataConnectors = [...this.state.dataConnectors]
                                 newDataConnectors = newDataConnectors.filter(dataConnector => dataConnector.name !== dataConnectorMetadata.name)
                                 this.safeSetState({dataConnectors: newDataConnectors})
                                 this.forceNewBrowser()
