@@ -7,6 +7,7 @@
 
 import * as React from 'react'
 import { UnControlled as CodeMirror } from 'react-codemirror2'
+import { Global } from '../../Global';
 
 // This code did not work to enable supporting all languages, though they don't recommend enabling all of them
 // import glob from 'glob'
@@ -27,6 +28,7 @@ interface IState {}
 export default class Editor extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div className='p-Widget lm-Widget jp-Editor jp-CodeMirrorEditor jp-InputArea-editor'>
                 <CodeMirror
