@@ -8,6 +8,7 @@
 import * as React from 'react'
 import ReactMarkdown from 'react-markdown'
 import gfm from 'remark-gfm';
+import { Global } from '../../Global';
 
 interface IProps {
     cell: any
@@ -19,6 +20,7 @@ interface IState {}
 export default class Markdown extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div className='jp-RenderedMarkdown jp-MarkdownOutput jp-RenderedHTMLCommon'>
                 <ReactMarkdown plugins={[gfm]} allowDangerousHtml >
