@@ -7,6 +7,7 @@
 
 import * as React from 'react'
 import InputArea from './InputArea'
+import { Global } from '../../Global';
 
 interface IProps {
     cell: any
@@ -18,6 +19,7 @@ interface IState {}
 export default class MarkdownCell extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <div className='p-Widget lm-Widget jp-Cell jp-MarkdownCell jp-Notebook-cell'>
                 <InputArea cell={this.props.cell} metadata={this.props.metadata} />
