@@ -893,6 +893,7 @@ interface IProps {
 }
 
 interface IState {
+	opened: boolean;
 	waiting: boolean;
 	spinning: boolean;
 	showDeleteJobPopup: boolean;
@@ -905,6 +906,7 @@ class AppComponent extends React.Component<IProps, IState> {
     constructor(props: IProps) {
         super(props);
         this.state = {
+			opened: false,
 			waiting: false,
 			spinning: false,
 			showDeleteJobPopup: false,
@@ -1043,11 +1045,11 @@ class AppComponent extends React.Component<IProps, IState> {
 		}
         return (
 			<>
-                <StatusWrapper key={this.props.app.uuid} statusColor={app.getAppStatus() == Status.Completed ? 'var(--jp-layout-color2)' : this.getStatusColor()}>
+                <StatusWrapper key={this.props.app.uuid} statusColor={app.getAppStatus() == Status.Completed ? 'var(--jp-layout-color2)' : this.getStatusColor()} opened={this.state.opened}>
                     <InfoSkirt
                         leftButton={
 							<ExtraInfo reminder='See details'>
-								<DetailsDialog app={this.props.app} />
+								<DetailsDialog app={this.props.app} onOpen={() => this.safeSetState({ opened: true })} onClose={() => this.safeSetState({ opened: false })}/>
 							</ExtraInfo>
 						}
                         rightButton={(this.props.app.requisitioning.completed && !this.props.app.requisitioning.error) && !this.props.app.running.completed ? (
