@@ -32,7 +32,9 @@ export class Machine {
     uuid: string
     name: string
     rate: number
+    promo: boolean
     state: string
+    app: string
 
     public getComponent(): React.CElement<any, MachineComponent> {
         return React.createElement(MachineComponent, {key: this.uuid, machine: this});
